==> haskell-hspec-contrib-0.5.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-DzCPoBusU76AQVgRcSywHg
key: hspec-contrib-0.5.0-DzCPoBusU76AQVgRcSywHg
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 8f71ba5c6ee09fab40885f0928237ad4
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-DzCPoBusU76AQVgRcSywHg
depends:
    base-4.11.1.0 hspec-core-2.5.1-vwTEGsDh5u6atWhxYIhsj
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hspec-core-2.5.1-vwTEGsDh5u6atWhxYIhsj=376bc4b598c88f17e28cd7a32349b385
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.0-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-7TrslhomB8AFrIkAhXYbho
key: hspec-contrib-0.5.0-7TrslhomB8AFrIkAhXYbho
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 2d2f4f0466189ccc0f31bdb69abbd6b2
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-7TrslhomB8AFrIkAhXYbho
depends:
    base-4.11.1.0 hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og=3ccb1c0f95ab08945910c24f3bef5232
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
